# -*- coding: utf-8 -*-
"""
    qserious
    ~~~~~
"""

from .qserious import deserialize, serialize, setKey, bracketsToDots, keysTobrackets

__version__ = '0.2.8'

# __all__ = ['deserialize', 'serialize', 'setKey', 'bracketsToDots', 'keysTobrackets']
